import { __spread, __decorate, __param, __metadata, __awaiter, __generator } from 'tslib';
import { InjectionToken, inject, PLATFORM_ID, isDevMode, Inject, ɵɵdefineInjectable, ɵɵinject, Injectable, APP_BOOTSTRAP_LISTENER, APP_INITIALIZER, NgModule } from '@angular/core';
import { Router, NavigationEnd } from '@angular/router';
import { isPlatformBrowser, DOCUMENT, CommonModule } from '@angular/common';

/**
 * Check if this environment can access Window object and return window or null if false.
 */
function getWindow(platformId) {
    return (isPlatformBrowser(platformId))
        ? window : null;
}
/**
 * Provide DOM Window reference or null if the environment is not a Browser.
 */
var WINDOW = new InjectionToken('hj-window', {
    providedIn: 'root',
    factory: function () { return getWindow(inject(PLATFORM_ID)); },
});

/**
 * Check if there is some global function called gtag on Window object, or create an empty function to doesn't brake codes...
 */
function getHjFn(window) {
    // // h.hj=h.hj||function(){(h.hj.q=h.hj.q||[]).push(arguments)};
    return (window)
        ? window.hj = (window.hj || function () {
            (window.hj.q = window.hj.q || []).push(arguments);
        })
        : null;
}
/**
 * Provides an injection token to access Google Analytics Gtag Function
 */
var NGX_HJ_FN = new InjectionToken('ngx-hj-fn', {
    providedIn: 'root',
    factory: function () { return getHjFn(inject(WINDOW)); }
});

/**
 * Provides a token to override default settings. You can use this token to enhance our library
 * and configure multiple sites/app on the same environment.
 */
var NGX_HOTJAR_SETTINGS_TOKEN = new InjectionToken('ngx-hotjar-settings', {
    factory: function () { return ({ trackingCode: '', version: 6, ennableTracing: false }); }
});

var NgxHotjarService = /** @class */ (function () {
    /** @ignore */
    function NgxHotjarService(
    /** @ignore */
    _hj, 
    /** @ignore */
    settings) {
        this._hj = _hj;
        this.settings = settings;
    }
    Object.defineProperty(NgxHotjarService.prototype, "lib", {
        /**
         * Provide direct access to the `hj.*` static functions. If the desired function is not available on type definition, you can cast to `any` as following.
         *
      ```typescript
      (hjService.lib as any).myBrandNewStaticFn()
      ```
         */
        get: function () {
            return this._hj;
        },
        enumerable: true,
        configurable: true
    });
    /** Expose Hotjar Function calls */
    NgxHotjarService.prototype.hj = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        try {
            this._hj.apply(this, __spread(args));
        }
        catch (err) {
            if (isDevMode() || this.settings.ennableTracing) {
                console.error(err.message);
            }
        }
    };
    /**
     * Fires an PageView event on Hotjar. Use this method to trigger an virtual url path. The same as
     *
  ```typescript
  hj('vpv', path)
  ```
     */
    NgxHotjarService.prototype.virtualPageView = function (path) {
        this.hj('vpv', path);
    };
    /**
     * Fires an event on Hotjar. Use this method to trigger events on forms and start video recordings. Same as
     *
  ```typescript
  hj('trigger', path)
  ```
     */
    NgxHotjarService.prototype.trigger = function (path) {
        this.hj('trigger', path);
    };
    NgxHotjarService.prototype.tagRecording = function (tagOrCollection) {
        var tags = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            tags[_i - 1] = arguments[_i];
        }
        // Retrocompatibility
        if (!Array.isArray(tagOrCollection)) {
            tagOrCollection = [tagOrCollection];
        }
        this.hj('tagRecording', tagOrCollection.concat.apply(tagOrCollection, __spread(tags)));
    };
    /**
     * This option is available in case you need to set up page change tracking manually
     * within your app's router.
     *
  ```typescript
  hj('stateChange', path)
  ```
     */
    NgxHotjarService.prototype.stateChange = function (path) {
        this.hj('stateChange', path);
    };
    /**
     * Signals form submission success
     *
  ```typescript
  hj('formSubmitSuccessful');
  ```
     */
    NgxHotjarService.prototype.formSubmitSuccessful = function () {
        this.hj('formSubmitSuccessful');
    };
    /**
     * Signals form submission failure
     *
  ```typescript
  hj('formSubmitFailed');
  ```
     */
    NgxHotjarService.prototype.formSubmitFailed = function () {
        this.hj('formSubmitFailed');
    };
    NgxHotjarService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [NGX_HJ_FN,] }] },
        { type: undefined, decorators: [{ type: Inject, args: [NGX_HOTJAR_SETTINGS_TOKEN,] }] }
    ]; };
    NgxHotjarService.ɵprov = ɵɵdefineInjectable({ factory: function NgxHotjarService_Factory() { return new NgxHotjarService(ɵɵinject(NGX_HJ_FN), ɵɵinject(NGX_HOTJAR_SETTINGS_TOKEN)); }, token: NgxHotjarService, providedIn: "root" });
    NgxHotjarService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(0, Inject(NGX_HJ_FN)),
        __param(1, Inject(NGX_HOTJAR_SETTINGS_TOKEN)),
        __metadata("design:paramtypes", [Function, Object])
    ], NgxHotjarService);
    return NgxHotjarService;
}());

/**
 * Provide a DI Configuration to attach Hotjar Trigger to Router Events at Angular Startup Cycle.
 */
var NGX_HOTJAR_ROUTER_INITIALIZER_PROVIDER = {
    provide: APP_BOOTSTRAP_LISTENER,
    multi: true,
    useFactory: HotjarRouterInitializer,
    deps: [
        NgxHotjarService
    ]
};
/**
 * Attach a listener to `NavigationEnd` Router event. So, every time Router finish the page resolution it should call `NavigationEnd` event.
 * We assume that NavigationEnd is the final page resolution and call Hotjar `stateChange` command.
 *
 * To avoid double binds, we also destroy the subscription when de Bootstrap Component is destroied. But, we don't know for sure
 * that this strategy does not cause double bind on multiple bootstrap components.
 *
 * We are using de component's injector reference to resolve Router, sou I hope there is no problem w/ double bing.
 *
 * If you have this problem, I encourage not Use NgxHotjarRouterModule and atach the listener on AppComponent initialization.
 */
function HotjarRouterInitializer(hjService) {
    var _this = this;
    return function (c) { return __awaiter(_this, void 0, void 0, function () {
        var router, subs;
        return __generator(this, function (_a) {
            router = c.injector.get(Router);
            subs = router
                .events
                .subscribe(function (event) {
                if (event instanceof NavigationEnd) {
                    hjService.stateChange(event.urlAfterRedirects);
                }
            });
            // Cleanup
            c.onDestroy(function () { return subs.unsubscribe(); });
            return [2 /*return*/];
        });
    }); };
}

/**
 * Provides a TOKEN to manually configure Hojtar tracking code by angular way.
 */
var NGX_HOTJAR_INITIALIZER_PROVIDER = {
    provide: APP_INITIALIZER,
    multi: true,
    useFactory: HotjarInitializer,
    deps: [
        NGX_HOTJAR_SETTINGS_TOKEN,
        DOCUMENT,
        WINDOW
    ]
};
/**
 * Configuration Factory to create hotjar install script tag and attache on DOM at angular initialization.
 */
function HotjarInitializer(settings, document, window) {
    var _this = this;
    return function () { return __awaiter(_this, void 0, void 0, function () {
        var hjWindow, head, script, uri;
        return __generator(this, function (_a) {
            if (!settings.trackingCode) {
                if (isDevMode()) {
                    console.error('Empty tracking code for Hotjar. Make sure to provide one when initializing NgxHotjarModule.');
                }
                return [2 /*return*/];
            }
            if (!document) {
                if (isDevMode()) {
                    console.error('Was not possible to access `document` instance. Make shure this environment works on a Broser like API');
                }
                return [2 /*return*/];
            }
            if (!window) {
                if (isDevMode()) {
                    console.error('Was not possible to access `window` api. Make sure this environment works like a browser.');
                }
                return [2 /*return*/];
            }
            hjWindow = Object.defineProperty(window, '_hjSettings', { value: { hjid: settings.trackingCode, hjsv: settings.version || 6 } });
            head = document.querySelector('head'), script = document.createElement('script'), uri = "https://static.hotjar.com/c/hotjar-" + hjWindow._hjSettings.hjid + ".js?sv=" + hjWindow._hjSettings.hjsv;
            script.async = true;
            script.src = (settings.uri || uri);
            head.appendChild(script);
            return [2 /*return*/];
        });
    }); };
}

/**
 * Install Hotjar scripts on Angular Startup life cycle if this environment is a Browser, otherwise just ignore this step.
 *
 * You shall add this module on the Gighest level module of your application, aka `AppModule`. When
 * setup this module, you also have to provide you hotjat tracking code and the version of script. The default version
 * is 6. We do not recoment to expose the tracking code in the repository, so please, use angular environment variable.
 *
 * ## Exemple of Use
 *
```typescript
\@NgModule({
  ...
  imports: [
    ...
    NgxHotjarModule.forRoot(envorinment.hj)
// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  ]
})
```
 */
var NgxHotjarModule = /** @class */ (function () {
    function NgxHotjarModule() {
    }
    NgxHotjarModule_1 = NgxHotjarModule;
    /**
     * Setup global settings and provide Hotjar Services.
     *
     * You private tracking code. This tracking code is also known as the same number as `SITE ID` inside Hotjar Dashboard.
     */
    NgxHotjarModule.forRoot = function (trackingCode, version, uri) {
        if (version === void 0) { version = 6; }
        return {
            ngModule: NgxHotjarModule_1,
            providers: [
                {
                    provide: NGX_HOTJAR_SETTINGS_TOKEN,
                    useValue: {
                        trackingCode: trackingCode,
                        version: version,
                        uri: uri
                    }
                },
                NGX_HOTJAR_INITIALIZER_PROVIDER,
            ]
        };
    };
    var NgxHotjarModule_1;
    NgxHotjarModule = NgxHotjarModule_1 = __decorate([
        NgModule({
            imports: [],
            declarations: [],
            exports: [],
            providers: []
        })
    ], NgxHotjarModule);
    return NgxHotjarModule;
}());

/**
 * Attach a listener to `NavigationEnd` Router event. So, every time Router finish the page resolution it should call `NavigationEnd` event.
 * We assume that NavigationEnd is the final page resolution and call Hotjar `stateChange` command.
 *
 * To avoid double binds, we also destroy the subscription when de Bootstrap Component is destroied. But, we don't know for sure
 * that this strategy does not cause double bind on multiple bootstrap components.
 *
 * We are using de component's injector reference to resolve Router, sou I hope there is no problem w/ double bing.
 *
 * If you have this problem, I encourage not Use NgxHotjarRouterModule and atach the listener on AppComponent initialization.
 *
 * This Module is just a sugar for:
 *
```typescript
constructor(private router: Router) {}
...
ngOnInit() {
  ...
  this.router
    .events
    .pipe(takeUntil(this.onDestroy$))
    .subscribe(event => {
      if (event instanceof NavigationEnd) {
        hjService.pageView(event.urlAfterRedirects, undefined);
      }
    });
```
 */
var NgxHotjarRouterModule = /** @class */ (function () {
    function NgxHotjarRouterModule() {
    }
    NgxHotjarRouterModule = __decorate([
        NgModule({
            imports: [
                CommonModule,
                NgxHotjarModule
            ],
            providers: [
                NGX_HOTJAR_ROUTER_INITIALIZER_PROVIDER
            ],
            declarations: []
        })
    ], NgxHotjarRouterModule);
    return NgxHotjarRouterModule;
}());

/*
 * Public API Surface of ngx-hotjar
 */

/**
 * Generated bundle index. Do not edit.
 */

export { HotjarInitializer, HotjarRouterInitializer, NGX_HJ_FN, NGX_HOTJAR_INITIALIZER_PROVIDER, NGX_HOTJAR_ROUTER_INITIALIZER_PROVIDER, NGX_HOTJAR_SETTINGS_TOKEN, NgxHotjarModule, NgxHotjarRouterModule, NgxHotjarService, WINDOW, getHjFn, getWindow };
//# sourceMappingURL=ngx-hotjar.js.map
